@@ -1,7 +1,10 @@
 import os
 import sys
+from typing import Any, Dict, List, Optional
+
 import click
 from jinja2 import Template
+
 from semversioner.storage import SemversionerFileSystemStorage
 
 ROOTDIR = os.getcwd()
@@ -21,13 +24,13 @@ Note: version releases in the 0.x.y range may introduce breaking changes.
 
 class Semversioner:
 
-    def __init__(self, path=ROOTDIR):
+    def __init__(self, path: str = ROOTDIR):
         self.fs = SemversionerFileSystemStorage(path=path)
 
-    def is_deprecated(self):
+    def is_deprecated(self) -> bool:
         return self.fs.is_deprecated()
 
-    def add_change(self, change_type, description):
+    def add_change(self, change_type: str, description: str) -> Dict[str, Any]:
         """ 
         Create a new changeset file.
 
@@ -47,7 +50,7 @@ class Semversioner:
 
         return self.fs.create_changeset(change_type=change_type, description=description)
 
-    def generate_changelog(self, version=None, template=DEFAULT_TEMPLATE):
+    def generate_changelog(self, version: Optional[str] = None, template: str = DEFAULT_TEMPLATE) -> str:
         """ 
         Generates the changelog.
 
@@ -66,7 +69,7 @@ class Semversioner:
 
         return Template(template, trim_blocks=True).render(releases=releases)
 
-    def release(self):
+    def release(self) -> Dict[str, Any]:
         """ 
         Performs the release.
 
@@ -84,13 +87,13 @@ class Semversioner:
         """
         changes = self.fs.list_changesets()
 
-        if len(changes) == 0:
-            click.secho("Error: No changes to release. Skipping release process.", fg='red')
-            sys.exit(-1)
-
         current_version_number = self.get_last_version()
         next_version_number = self.get_next_version(changes, current_version_number)
 
+        if next_version_number is None:
+            click.secho("Error: No changes to release. Skipping release process.", fg='red')
+            sys.exit(-1)
+
         click.echo("Releasing version: %s -> %s" % (current_version_number, next_version_number))
         self.fs.create_version(version=next_version_number, changes=changes)
         self.fs.remove_all_changesets()
@@ -100,21 +103,22 @@ class Semversioner:
             'new_version': next_version_number
         }
 
-    def get_last_version(self):
+    def get_last_version(self) -> str:
         """ 
         Gets the current version.
 
         """
         return self.fs.get_last_version() or INITIAL_VERSION
 
-    def get_next_version(self, changes, current_version_number):
+    def get_next_version(self, changes: List[Dict[str, Any]], current_version_number: str) -> Optional[str]:
         if len(changes) == 0:
             return None
-        release_type = sorted(list(map(lambda x: x['type'], changes)))[0]
-        next_version = self._get_next_version_from_type(current_version_number, release_type)
+
+        release_type: str = sorted(list(map(lambda x: x['type'], changes)))[0]  # type: ignore
+        next_version: str = self._get_next_version_from_type(current_version_number, release_type)
         return next_version
 
-    def get_status(self):
+    def get_status(self) -> Dict[str, Any]:
         """
         Displays the status of the working directory.
         """
@@ -128,7 +132,7 @@ class Semversioner:
             'unreleased_changes': changes,
         }
 
-    def _get_next_version_from_type(self, current_version, release_type):
+    def _get_next_version_from_type(self, current_version: str, release_type: str) -> str:
         """ 
         Returns a string like '1.0.0'.
         """
